<img src='https://img.shields.io/pypi/l/attis.svg'> <img src='https://img.shields.io/pypi/v/attis.svg'> <img src='https://img.shields.io/pypi/dm/attis.svg'> <img src='https://img.shields.io/pypi/pyversions/attis.svg'> <img src='https://img.shields.io/badge/code%20style-black-000000.svg'>

# Attis
A flexible framework for Python

# Installation

```
$ sudo pip3 install attis
```

# Usage
